Paddle Design Compiler
PaddlePaddle/Paddle
A skill your agent uses when working with Paddle 3.0 compiler full pipeline: SOT (Symbolic Opcode Translator) for bytecode-level dy2st graph capture, PIR (Paddle IR) for SSA-based intermediate…
Implements request-to-token-pool copies for Triton kernels on Ascend NPUs, replacing loop-carried vector offsets with fixed-offset block loops that compile reliably.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill assign-triton-ascend-token-pools -a claude-codeProject install by default; add -g for ~/.claude/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit assign-triton-ascend-token-pools --agent claude-codeProject scope by default; add --scope user for a personal install. Needs GitHub CLI 2.90.0 or later (public preview).
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .claude/skills && cp -r skills-src/skills/assign-triton-ascend-token-pools .claude/skills/assign-triton-ascend-token-pools && rm -rf skills-srcUse ~/.claude/skills/ instead of .claude/skills for a personal install. The folder must contain SKILL.md.
Claude Code skills documentation · loads skills from .claude/skills/
Install the "assign-triton-ascend-token-pools" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/assign-triton-ascend-token-pools into .claude/skills/assign-triton-ascend-token-pools/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "assign-triton-ascend-token-pools", then confirm the skill loads.Claude Code copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$skill-installer install https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/assign-triton-ascend-token-poolsType this inside Codex. $skill-installer <name> installs a curated skill from openai/skills. The installer writes to $CODEX_HOME/skills (default ~/.codex/skills). Restart Codex if the skill does not show up.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill assign-triton-ascend-token-pools -a codexProject install goes to .agents/skills/; add -g for ~/.codex/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit assign-triton-ascend-token-pools --agent codexProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .agents/skills && cp -r skills-src/skills/assign-triton-ascend-token-pools .agents/skills/assign-triton-ascend-token-pools && rm -rf skills-srcUse ~/.agents/skills/ instead of .agents/skills for a personal install.
Codex skills documentation · loads skills from .agents/skills/
Install the "assign-triton-ascend-token-pools" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/assign-triton-ascend-token-pools into .agents/skills/assign-triton-ascend-token-pools/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "assign-triton-ascend-token-pools", then confirm the skill loads.Codex copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill assign-triton-ascend-token-pools -a cursorProject install goes to .agents/skills/; add -g for ~/.cursor/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit assign-triton-ascend-token-pools --agent cursorProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .cursor/skills && cp -r skills-src/skills/assign-triton-ascend-token-pools .cursor/skills/assign-triton-ascend-token-pools && rm -rf skills-srcUse ~/.cursor/skills/ instead of .cursor/skills for a personal install.
Cursor skills documentation · loads skills from .cursor/skills/, .agents/skills/, .claude/skills/, .codex/skills/
Install the "assign-triton-ascend-token-pools" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/assign-triton-ascend-token-pools into .cursor/skills/assign-triton-ascend-token-pools/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "assign-triton-ascend-token-pools", then confirm the skill loads.Cursor copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ gemini skills install https://github.com/Krusty84/triton-ascend-agent-dev-kit.git --path skills/assign-triton-ascend-token-pools--scope user (default) or --scope workspace; --path is the subfolder of the repo that holds the skill; --consent skips the security confirmation prompt.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill assign-triton-ascend-token-pools -a gemini-cliProject install goes to .agents/skills/; add -g for ~/.gemini/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit assign-triton-ascend-token-pools --agent gemini-cliProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .gemini/skills && cp -r skills-src/skills/assign-triton-ascend-token-pools .gemini/skills/assign-triton-ascend-token-pools && rm -rf skills-srcUse ~/.gemini/skills/ instead of .gemini/skills for a personal install, then run /skills reload.
Gemini CLI skills documentation · loads skills from .gemini/skills/, .agents/skills/
Install the "assign-triton-ascend-token-pools" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/assign-triton-ascend-token-pools into .gemini/skills/assign-triton-ascend-token-pools/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "assign-triton-ascend-token-pools", then confirm the skill loads.Gemini CLI copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit assign-triton-ascend-token-poolsInstalls for Copilot at project scope by default; add --scope user for a personal install. Preview a skill first with gh skill preview. Needs GitHub CLI 2.90.0 or later (public preview).
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill assign-triton-ascend-token-pools -a github-copilotProject install goes to .agents/skills/; add -g for ~/.copilot/skills/.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .github/skills && cp -r skills-src/skills/assign-triton-ascend-token-pools .github/skills/assign-triton-ascend-token-pools && rm -rf skills-srcUse ~/.copilot/skills/ instead of .github/skills for a personal install. Commit .github/skills so cloud agent and code review can use it.
GitHub Copilot skills documentation · loads skills from .github/skills/, .claude/skills/, .agents/skills/
Install the "assign-triton-ascend-token-pools" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/assign-triton-ascend-token-pools into .github/skills/assign-triton-ascend-token-pools/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "assign-triton-ascend-token-pools", then confirm the skill loads.GitHub Copilot copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill assign-triton-ascend-token-pools -a opencodeOpenCode documents no install command of its own. Project install goes to .agents/skills/; add -g for ~/.config/opencode/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit assign-triton-ascend-token-pools --agent opencodeProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .opencode/skills && cp -r skills-src/skills/assign-triton-ascend-token-pools .opencode/skills/assign-triton-ascend-token-pools && rm -rf skills-srcUse ~/.config/opencode/skills/ instead of .opencode/skills for a personal install.
OpenCode skills documentation · loads skills from .opencode/skills/, .claude/skills/, .agents/skills/
Install the "assign-triton-ascend-token-pools" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/assign-triton-ascend-token-pools into .opencode/skills/assign-triton-ascend-token-pools/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "assign-triton-ascend-token-pools", then confirm the skill loads.OpenCode copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
assign-triton-ascend-token-poolsImplements request-to-token-pool copies for Triton kernels on Ascend NPUs, replacing loop-carried vector offsets with fixed-offset block loops that compile reliably.
The goal is to copy each request's contiguous cache segment into the correct row and token range of a request-to-token table, porting SGLang-style KV cache assignment to Ascend hardware. The workflow launches one program per request, loads its kv_start, kv_end and destination pool row, sums the lengths of all earlier requests to find this request's source offset in the concatenated cache, and copies the resulting span in fixed BLOCK_SIZE chunks using int32 metadata when every length, offset and pool index fits.
A set of Ascend-specific guardrails follows: use saved offsets rather than the first block's offsets when masking every loop iteration, compute each iteration's offset as i times BLOCK_SIZE plus a base rather than mutating a vector offset across iterations, keep BS_UPPER a safe compile-time bound with entries beyond the program ID masked out, validate that start is less than or equal to end within the pool length, and switch to int64 whenever a prefix sum or flattened address could exceed int32 range.
Verification compares the kernel's output against a plain CPU loop over requests, specifically exercising spans longer than BLOCK_SIZE, a partial final chunk, empty spans, non-uniform lengths and a boundary case near int32 overflow.
5 steps, taken from the first numbered list in SKILL.md.
Read from SKILL.md and the folder at commit 4ab5ee7. It shows what the files ask for, not the result of running them.
Pre-approves nothing: there is no allowed-tools line, so your agent's usual permission prompts apply.
From allowed-tools in the SKILL.md frontmatter.
No scripts in the folder and no shell commands in SKILL.md (its code samples are python).
From the folder's file list and the shell code blocks in SKILL.md.
No URLs in SKILL.md.
From URLs in SKILL.md, links to its own repository left out.
Names no API keys, tokens, secrets or passwords.
From names ending in _API_KEY, _TOKEN, _SECRET, _KEY or _PASSWORD in SKILL.md.
Triton-Ascend Token Pool Assignment loads about 564 tokens when it runs. Until then it costs about 96 tokens; SKILL.md has 169 words of instructions outside code blocks.
Estimates: characters ÷ 4, the usual rule of thumb; real counts depend on the model's tokenizer. Scripts and assets cost tokens only if the agent reads them.
The automated check found no risky patterns in SKILL.md.
Automated static check — not a guarantee. Review scripts before installing. It scans the text of SKILL.md for risky patterns (piping downloads into a shell, reading credential files, hidden Unicode, destructive commands); files beside SKILL.md are not scanned.
The full file from Krusty84/triton-ascend-agent-dev-kit at commit 4ab5ee7, republished under its Apache-2.0 licence (© Krusty84). 169 words, ~564 tokens.
.claude/skills/assign-triton-ascend-token-pools/SKILL.md (or your agent's skills folder).Copy each request's contiguous cache segment into the correct row and token range of a request-to-token table.
prefix_offsets = tl.arange(0, BS_UPPER)
prior = prefix_offsets < pid
starts = tl.load(start_ptr + prefix_offsets, mask=prior, other=0)
ends = tl.load(end_ptr + prefix_offsets, mask=prior, other=0)
source_start = tl.sum(ends - starts, axis=0)
base = tl.arange(0, BLOCK_SIZE)
num_loops = tl.cdiv(kv_end - kv_start, BLOCK_SIZE)
for i in range(num_loops):
load_offsets = source_start + i * BLOCK_SIZE + base
save_offsets = kv_start + i * BLOCK_SIZE + base
mask = save_offsets < kv_end
values = tl.load(out_cache + load_offsets, mask=mask)
tl.store(token_pool + save_offsets, values, mask=mask)Compare with a CPU loop over requests. Include spans longer than BLOCK_SIZE, a partial final chunk, empty spans, nonuniform lengths, and an int32-overflow boundary.
© Krusty84, Apache-2.0. Rendered from Markdown: HTML in the file is shown as text, images as links, and headings moved down two levels. Raw file
Just SKILL.md in skills/assign-triton-ascend-token-pools of Krusty84/triton-ascend-agent-dev-kit.
Open the folder on GitHubat commit 4ab5ee7
Triton-Ascend Token Pool Assignment next to the 5 skills that share the most tags, products or categories with it. Stars are the repository's; “used in” counts other GitHub owners with a copy.
| Skill | Stars | Used in | Tokens | Auto-check | Licence | Repo updated |
|---|---|---|---|---|---|---|
| Triton-Ascend Token Pool Assignment this skillKrusty84/triton-ascend-agent-dev-kit | 106 | — | ~564 | Automated safety check: Pass | Apache-2.0 | |
| Paddle Design CompilerPaddlePaddle/Paddle | 24k | — | ~3.6k | Automated safety check: Pass | Apache-2.0 | |
| Hugging Face Local Model Evalshuggingface/skills | 11k | 2 repos | ~1.6k | Automated safety check: Pass | Apache-2.0 | |
| Cuda Index Widthpytorch/pytorch | 104k | — | ~1.6k | Automated safety check: Pass | Custom licence | |
| Leetcuda Cpp Kernelxlite-dev/LeetCUDA | 12k | — | ~3.5k | Automated safety check: Pass | GPL-3.0 | |
| Liger Autopatchlinkedin/Liger-Kernel | 6.7k | — | ~1.3k | Automated safety check: Pass | BSD-2-Clause |
PaddlePaddle/Paddle
A skill your agent uses when working with Paddle 3.0 compiler full pipeline: SOT (Symbolic Opcode Translator) for bytecode-level dy2st graph capture, PIR (Paddle IR) for SSA-based intermediate…
huggingface/skills
Runs evaluations of Hugging Face Hub models on local hardware with inspect-ai or lighteval, and helps choose between vLLM, Transformers and accelerate backends.
pytorch/pytorch
Choose 32-bit vs 64-bit index math in PyTorch CUDA kernels. An agent skill from pytorch/pytorch.
xlite-dev/LeetCUDA
LeetCUDA 中文技术书(584 页,XeLaTeX 源)按需查阅 skill——写、优化、调试或 review CUDA C++/PTX kernel 时的权威参考路由层。当任务涉及:GPU 架构/Roofline/ occupancy、向量化与 coalescing、warp/block reduce、softmax(online/LSE merge)、…
linkedin/Liger-Kernel
Adds Liger Kernel support for a new HuggingFace Transformers model, or modifies existing monkey-patching.
internet-court/internet-court-skill
Guides building on the 0G Compute Network, a decentralized GPU marketplace for AI inference and fine-tuning, with SDK patterns and CLI commands.
Krusty84/triton-ascend-agent-dev-kit
Writes a Triton kernel pattern for Ascend NPU that gathers several indexed token rows per program into an on-chip buffer and stores one contiguous output tile, for MoE-style token reordering.
Krusty84/triton-ascend-agent-dev-kit
Builds Triton-Ascend kernels that pack sorted token assignments into fixed expert-capacity tensors, restore top-k outputs and compute router-weight gradients on Ascend NPUs.
Krusty84/triton-ascend-agent-dev-kit
Guides building a FlashAttention-v2-style fused forward attention kernel for Triton-Ascend on Ascend NPU, with online softmax, causal staging and float32 accumulation.
Krusty84/triton-ascend-agent-dev-kit
Builds a fused row-wise softmax kernel for Triton-Ascend that reads and writes each row once, handling padding, strides and masked loads on Ascend NPUs.
Krusty84/triton-ascend-agent-dev-kit
Build a fused forward LayerNorm kernel for Triton-Ascend with row-wise mean and variance reductions, float32 accumulation, affine weight and bias, and masked feature tiles.
Krusty84/triton-ascend-agent-dev-kit
Build Ascend-friendly MoE gather, scatter, and router-weight-gradient kernels with vector-core-sized grids, UB-aware row/column tiling, and CANN slice extensions.
Categories
Implements request-to-token-pool copies for Triton kernels on Ascend NPUs, replacing loop-carried vector offsets with fixed-offset block loops that compile reliably. The goal is to copy each request's contiguous cache segment into the correct row and token range of a request-to-token table, porting SGLang-style KV cache assignment to Ascend hardware. The workflow launches one program per request, loads its kv_start, kv_end and destination pool row, sums the lengths of all earlier requests to find this request's source offset in the concatenated cache, and copies the resulting span in fixed BLOCK_SIZE chunks using int32 metadata when every length, offset and pool index fits.
Triton-Ascend Token Pool Assignment fits situations like: porting SGLang-style KV cache assignment to Ascend NPU kernels; replacing a loop-carried vector offset that compiles poorly on Ascend; copying variable-length request spans out of a concatenated cache correctly.
Run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill assign-triton-ascend-token-pools -a claude-code`. Or copy the skill folder (skills/assign-triton-ascend-token-pools in Krusty84/triton-ascend-agent-dev-kit) into .claude/skills/assign-triton-ascend-token-pools in your project. Claude Code loads it when a task matches its description.
Run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill assign-triton-ascend-token-pools -a codex`. Or copy the skill folder (skills/assign-triton-ascend-token-pools in Krusty84/triton-ascend-agent-dev-kit) into .agents/skills/assign-triton-ascend-token-pools in your project. Codex loads it when a task matches its description.
Cursor, Gemini CLI, GitHub Copilot and OpenCode also load SKILL.md folders. With the skills CLI, run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill assign-triton-ascend-token-pools -a cursor` (or -a gemini-cli, github-copilot or opencode for the others). To copy it by hand, put the folder in .cursor/skills/assign-triton-ascend-token-pools, .gemini/skills/assign-triton-ascend-token-pools, .github/skills/assign-triton-ascend-token-pools and .opencode/skills/assign-triton-ascend-token-pools in your project.
SKILL.md names no scripts, command-line tools or credentials: Triton-Ascend Token Pool Assignment is instructions for the agent only. Our summary lists: A Triton-Ascend development setup targeting Ascend NPU hardware.
SKILL.md contains no URLs. Any network use would come from the scripts or tools the agent runs. This is read from the text; nothing was executed.
Our automated static check of SKILL.md found no risky patterns, such as piping downloads into a shell, reading credential files or hidden Unicode. It is not a guarantee. Review the folder before installing.
Triton-Ascend Token Pool Assignment is published under the Apache-2.0 licence (the repository's licence). It allows redistribution, so the full SKILL.md is shown on this page.
About 564 tokens (SKILL.md is roughly 2.3k characters). Agents keep only the skill's name and description in context until a task matches; then they load SKILL.md in full.
Skills that share tags, products or a category with Triton-Ascend Token Pool Assignment: Paddle Design Compiler (PaddlePaddle/Paddle, 24k stars), Hugging Face Local Model Evals (huggingface/skills, 11k stars), Cuda Index Width (pytorch/pytorch, 104k stars) and Leetcuda Cpp Kernel (xlite-dev/LeetCUDA, 12k stars). The comparison table on this page puts their stars, adoption, token cost, safety result and licence side by side.
Krusty84 (a GitHub user) maintains it in Krusty84/triton-ascend-agent-dev-kit, which has 106 GitHub stars. The repository holds 23 skills in this directory. The repository was last updated on August 15, 2026.
Source: Krusty84/triton-ascend-agent-dev-kit on GitHub. Facts on this page come from the repository at the commit we read; the author's words are quoted as theirs.